X-Git-Url: https://git.rapsys.eu/airbundle/blobdiff_plain/9d7bd791a50db10238db21b81b6955906f828325..9f8c7e7014e3dfd8823926a3fc21c1fb2fe60de5:/RapsysAirBundle.php

diff --git a/RapsysAirBundle.php b/RapsysAirBundle.php
index 0bad725..6096959 100644
--- a/RapsysAirBundle.php
+++ b/RapsysAirBundle.php
@@ -11,16 +11,27 @@
 
 namespace Rapsys\AirBundle;
 
-use Symfony\Component\DependencyInjection\Container;
+use Symfony\Component\DependencyInjection\Extension\ExtensionInterface;
 use Symfony\Component\HttpKernel\Bundle\Bundle;
 
+/**
+ * {@inheritdoc}
+ */
 class RapsysAirBundle extends Bundle {
+	/**
+	 * {@inheritdoc}
+	 */
+	public function getContainerExtension(): ?ExtensionInterface {
+		//Return created container extension
+		return $this->createContainerExtension();
+	}
+
 	/**
 	 * Return bundle alias
 	 *
 	 * @return string The bundle alias
 	 */
-    public static function getAlias(): string {
+	public static function getAlias(): string {
 		//With namespace
 		if ($npos = strrpos(static::class, '\\')) {
 			//Set name pos
@@ -40,7 +51,17 @@ class RapsysAirBundle extends Bundle {
 			$bpos = strlen(static::class) - $npos;
 		}
 
-		//Return underscored lowercase bundle alias
-		return Container::underscore(substr(static::class, $npos, $bpos));
-    }
+		//Return lowercase bundle alias
+		return strtolower(substr(static::class, $npos, $bpos));
+	}
+
+	/**
+	 * Return bundle version
+	 *
+	 * @return string The bundle version
+	 */
+	public static function getVersion(): string {
+		//Return version
+		return '0.4.0';
+	}
 }